%Plot results
close all
load('Data23_7_NEW.mat');
load('MeshData23_7.mat')
%contains:
% Eactin,P,Ewall, M, and Data{} for all Eactin values, with following
% columns:

%Columns:
%1. P 
%2. Eint
%3. Ewall
%4. M
%5. d
%6. z-component of integrated contact pressure (N)
%7. Displacement at tip (dz) (um)
%8. Contact area (m^2)
%9. Indented volume: integral of dz over top surface, m^3
%10. Fz on bottom (N)
%11. integrated shell displacement: int sqrt(dr^2+dz^2) over shell surface (m^3)
%12. Total elastic strain energy in shell, int W over shell (J)


%Choose parameters
ip=1;  %pressure index
iw=1;  %Ewall index

CM=jet(length(Eactin));
CM(1,:)=[0 0 0];
EForLegend=[inf,600,500,400,300,200,100,1,0];

%1. Plot snapshots for two cases:
i_f=2;
figure
iac=[9,2];  %plot mesh for these actin moduli
Eact=Eactin(iac);
Ro=par.R;
for i=1:length(iac)
    subplot(1,length(iac),i)
    hold on
    A=MeshData{iac(i)}.sol;
    isub=find(A(:,2)<-Ro+1e-10);   %Negatve y: subtrate
    iact=setdiff(1:size(A,1),isub);
    ishell=find(abs(A(:,2).^2+A(:,1).^2-Ro^2)<1e-10);
    Substrate=A(isub,:);
    Sphere=A(iact,:);
    Shell=sortrows(A(ishell,:));
    X=Substrate(:,1);
    Y=Substrate(:,2);
    XS=Shell(:,1);
    YS=Shell(:,2);
    dXS=Shell(:,2+(i_f-1)*7+1);
    dYS=Shell(:,2+(i_f-1)*7+2);
    
    dX=Substrate(:,2+(i_f-1)*7+1);
    dY=Substrate(:,2+(i_f-1)*7+2);
    ep3=Substrate(:,2+(i_f-1)*7+5);
    x=X+dX;
    y=Y+dY;
   
    
    tri=delaunay(x,y);
    trisurf(tri,x,y,ep3)
    view(2)
    shading interp
    colorbar
    caxis([-0.15 0])
    dXS=Shell(:,2+(i_f-1)*7+1);
    dYS=Shell(:,2+(i_f-1)*7+2);
    plot(XS+dXS,YS+dYS,'k-','LineWidth',4)
    xlim([0 5])
    ylim([-9 -3])
    %tit=['Principal strain for Eactin=',num2str(Eact(i))];
    %title(tit);
end


%2. Plot strain energy in shell versus force
figure,hold on
clear leg
curve=0;
for ii=[9,7:-1:1]
    curve=curve+1;
    A=Data{ii}; 
    d=A(2:end,5);       %d
    fz=A(2:end,10);    %force
    w=A(2:end,7);       %tip displacement
    u=d-w;              %max substrate indentation
    CA=A(2:end,8);      %contact area
    W=A(2:end,12);      %strain energy
    V=A(2:end,9);       %indented volume
    
    plot(1e6*fz,W,'-','Color', CM(ii,:),'LineWidth',3)
    
    leg{curve}=num2str(EForLegend(ii));
end
legend(leg)
xlabel('Indentation force (uN)')
ylabel('Strain energy shell (J)')
%title('Strain energy in shell')

%3.Create mastercurve, by renormalizing force axis
figure,hold on
clear leg
Wref=0.5e-11;
Fref=[];
curve=0;
for ii=[9,7:-1:2]
    curve=curve+1;
    A=Data{ii}; 
    d=A(2:end,5);       %d
    fz=A(2:end,10);    %force
    w=A(2:end,7);       %tip displacement
    u=d-w;              %max substrate indentation
    CA=A(2:end,8);      %contact area
    W=A(2:end,12);      %strain energy
    V=A(2:end,9);       %indented volume

    %Find f at W=Wref;
    [ii1,jj1]=min((W-Wref).^2);
    Fref(ii)=fz(jj1);
    %if ii==9
    %    Fref0=Fref(ii);
    %end
    %Fref(ii)=Fref(ii)/Fref0;
    plot(fz/Fref(ii),W,'-','Color', CM(ii,:),'LineWidth',3)

    leg{curve}=num2str(EForLegend(ii));
end
legend(leg)
xlabel('F/F^*')
ylabel('Strain energy (J)')
%title('Normalized strain energy')

%4.Critical force versus Actin modulus
figure,hold on
clear leg
ii=[9,7:-1:2];
plot(Eactin(ii),Fref(ii),'o-')
xlabel('Actin gel modulus (kPa)')
ylabel('F^*')
%title('Normalized strain energy')
